﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Net;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Documents;
using System.Windows.Input;
using System.Windows.Media;
using System.Windows.Media.Animation;
using System.Windows.Shapes;
using Infragistics.Controls.Grids;

namespace xamGridFilteringDemo
{
    public partial class MainPage : UserControl
    {
        public MainPage()
        {
            InitializeComponent();
            
        }

        public class Sweets : FilterOperand
        {
            protected override string DefaultDisplayName
            {
                get
                {
                    return "Sweets";
                }
            }

            public override bool RequiresFilteringInput
            {
                get
                {
                    return false;
                }
            }

            // Create filter expression that returns all categories that have 'sweet' in their description
            public override System.Linq.Expressions.Expression FilteringExpression(object value)
            {
                System.Linq.Expressions.Expression<Func<Category, bool>> expr = category => category != null && category.Description.ToLower().Contains("sweet");
                return expr;
            }
        }

        private void xamGrid_Loaded(object sender, RoutedEventArgs e)
        {
            //Include the filter operand to the row filter used in custom filter dialogs
            FilterColumnSettings filterColSettings = this.xamGrid.Columns.DataColumns["Description"].FilterColumnSettings;
            filterColSettings.RowFilterOperands.Add(new Sweets());
            //Also include it in the dropdown menu:
            var filterMenuOperands = this.xamGrid.Columns.DataColumns["Description"].FilterColumnSettings.FilterMenuOperands;
            FilterMenuTrackingObject filterMenuTrackObj = new FilterMenuTrackingObject(new Sweets());
            filterMenuOperands.ElementAt(0).Children.Add(filterMenuTrackObj);

            //Add the 'Begins With' filter
            //Include the filter operand to the row filter used in custom filter dialogs
             DataTemplate filterIcon = (DataTemplate)this.Resources["BeginsWithIcon"];
            filterColSettings = this.xamGrid.Columns.DataColumns["CategoryID"].FilterColumnSettings;
            filterColSettings.RowFilterOperands.Add(new BeginsWith() { Icon = filterIcon });
            //Also include it in the dropdown menu:
            filterMenuOperands = this.xamGrid.Columns.DataColumns["CategoryID"].FilterColumnSettings.FilterMenuOperands;
            filterMenuTrackObj = new FilterMenuTrackingObject(new BeginsWith());
            filterMenuOperands.ElementAt(0).Children.Add(filterMenuTrackObj);
        }

        public class BeginsWith : FilterOperand
        {
            protected override string DefaultDisplayName
            {
                get
                {
                    return "Begins with...";
                }
            }

            public override bool RequiresFilteringInput
            {
                get
                {
                    return true;
                }
            }

            // Create filter expression that returns all categories that have 'sweet' in their description
            public override System.Linq.Expressions.Expression FilteringExpression(object value)
            {
                System.Linq.Expressions.Expression<Func<Category, bool>> expr = category => category != null && category.CategoryID.ToString().StartsWith(value.ToString());
                return expr;
            }
        }

    }
}
